wlanutilities/wlansniffer/mainapplication/inc/wsfdetailsviewmodel.h
branchRCL_3
changeset 12 981afc7d3841
parent 0 56b72877c1cb
--- a/wlanutilities/wlansniffer/mainapplication/inc/wsfdetailsviewmodel.h	Mon Mar 15 12:44:54 2010 +0200
+++ b/wlanutilities/wlansniffer/mainapplication/inc/wsfdetailsviewmodel.h	Wed Mar 31 23:17:49 2010 +0300
@@ -231,11 +231,11 @@
         HBufC* FormatCoverageLC();
     
         /**
          * Formats wlan speed to string 
          * @since S60 v5.0
          * @return formated string
          */        
-        HBufC* FormatSpeedLC();
+        HBufC* FormatTechnologyLC();
     
         /**
         * Calculate number of visible (Not hidden) WLANs
@@ -231,11 +231,11 @@
     
         /**
-         * Formats wlan speed to string 
-         * @since S60 v5.0
+         * Formats wlan technology to string 
+         * @since S60 v5.2
          * @return formated string
          */        